@@ -296,7 +296,6 @@ class ContentItem(BaseModel):
 class ScreenshotDefinition(BaseModel):
     """Screenshot definition with content items."""
 
-    name: str = Field(..., description="Screenshot name")
     background: Optional[GradientConfig] = Field(
         default=None,
         description="Background configuration (optional - uses default if not specified)",
@@ -319,8 +318,8 @@ class ProjectConfig(BaseModel):
         default=["iPhone 15 Pro Portrait"], description="Target devices"
     )
     defaults: Optional[Dict] = Field(default=None, description="Default settings")
-    screenshots: List[ScreenshotDefinition] = Field(
-        ..., description="Screenshot definitions"
+    screenshots: Dict[str, ScreenshotDefinition] = Field(
+        ..., description="Screenshot definitions mapped by ID"
     )
 
     @validator("project")
